faradaycommands - Command Application Toolset
=============================================

Faraday Commands is a collection of packet creation tools and predefined common commands focused on the command and control functionality that the Faraday "Commands" application provides. The application for Commanding contains its own packet format as observed in the OSI layer and this toolset provides easy to use commands and tools to create command packets.

.. automodule:: faradaycommands
    :members:
